]> git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - cmd.h
vid: misc cleanups
[xonotic/darkplaces.git] / cmd.h
diff --git a/cmd.h b/cmd.h
index f7b3b4d1078b31ae4d7bb902dfca225b1fcb9b5f..99241fcf753618591fa61052398d2280119702d4 100644 (file)
--- a/cmd.h
+++ b/cmd.h
@@ -57,10 +57,11 @@ struct cmd_state_s;
 #define CF_USERINFO             (1<<9)  // command or cvar used to communicate userinfo to the server
 #define CF_PERSISTENT           (1<<10) // cvar must not be reset on gametype switch (such as scr_screenshot_name, which otherwise isn't set to the mod name properly)
 #define CF_PRIVATE              (1<<11) // cvar should not be $ expanded or sent to the server under any circumstances (rcon_password, etc)
-#define CF_MAXFLAGSVAL          4095    // used to determine if flags is valid
+#define CF_MAXFLAGSVAL          ((1<<12) - 1)    // used to determine if flags is valid
 // for internal use only!
+#define CF_REGISTERED (1<<29)  // created by Cvar_RegisterVariable()
 #define CF_DEFAULTSET (1<<30)
-#define CF_ALLOCATED (1<<31)
+#define CF_ALLOCATED (1<<31)   // created by Cvar_Get() (console or QC)
 
 #define CF_SHARED 3
 
@@ -90,6 +91,7 @@ typedef struct cmd_function_s
        const char *description;
        xcommand_t function;
        qbool qcfunc;
+       struct cmd_function_s *overridden; // the engine cmd overriden by this QC cmd, if applicable
        qbool autofunc;
        qbool initstate; // indicates this command existed at init
 } cmd_function_t;
@@ -125,6 +127,7 @@ typedef struct cmd_state_s
        struct mempool_s *mempool;
 
        int argc;
+       const char *cmdline;
        const char *argv[MAX_ARGS];
        const char *null_string;
        const char *args;
@@ -141,23 +144,21 @@ typedef struct cmd_state_s
 
        int cmd_flags; // cmd flags that identify this interpreter
 
-       /*
-        * If a requested flag matches auto_flags, a command will be
-        * added to a given interpreter with auto_function. For example,
-        * a CF_SERVER_FROM_CLIENT command should be automatically added
-        * to the client interpreter as CL_ForwardToServer_f. It can be
-        * overridden at any time.
-        */
-       int auto_flags;
-       xcommand_t auto_function;
+       qbool (*Handle)(struct cmd_state_s *, struct cmd_function_s *, const char *, enum cmd_source_s);
+       qbool (*NotFound)(struct cmd_state_s *, struct cmd_function_s *, const char *, enum cmd_source_s);
 }
 cmd_state_t;
 
+qbool Cmd_Callback(cmd_state_t *cmd, cmd_function_t *func, const char *text, cmd_source_t src);
+qbool Cmd_CL_Callback(cmd_state_t *cmd, cmd_function_t *func, const char *text, cmd_source_t src);
+qbool Cmd_SV_Callback(cmd_state_t *cmd, cmd_function_t *func, const char *text, cmd_source_t src);
+qbool Cmd_SV_NotFound(cmd_state_t *cmd, cmd_function_t *func, const char *text, cmd_source_t src);
+
 typedef struct cmd_input_s
 {
        llist_t list;
        cmd_state_t *source;
-       double delay;
+       vec_t delay;
        size_t size;
        size_t length;
        char *text;
@@ -167,15 +168,12 @@ typedef struct cmd_input_s
 extern cmd_userdefined_t cmd_userdefined_all; // aliases and csqc functions
 extern cmd_userdefined_t cmd_userdefined_null; // intentionally empty
 
-// command interpreter for client commands injected by CSQC, MQC or client engine code
-// uses cmddefs_all
-extern cmd_state_t cmd_client;
-// command interpreter for server commands injected by MQC, SVQC, menu engine code or server engine code
+// command interpreter for local commands injected by SVQC, CSQC, MQC, server or client engine code
 // uses cmddefs_all
-extern cmd_state_t cmd_server;
+extern cmd_state_t *cmd_local;
 // command interpreter for server commands received over network from clients
 // uses cmddefs_null
-extern cmd_state_t cmd_serverfromclient;
+extern cmd_state_t *cmd_serverfromclient;
 
 extern qbool host_stuffcmdsrun;
 
@@ -282,5 +280,7 @@ qbool Cmd_QuoteString(char *out, size_t outlen, const char *in, const char *quot
 
 void Cmd_ClearCSQCCommands (cmd_state_t *cmd);
 
+void Cmd_NoOperation_f(cmd_state_t *cmd);
+
 #endif